@@ -89,8 +89,7 @@ class Recipe(BaseSlapRecipe):
               test_suite_master_url=self.parameter_dict.get(
                                 'test_suite_master_url', None),
               test_suite_name=self.parameter_dict.get('test_suite_name'),
-              #slave_name=self.parameter_dict['slave_name'],
-              #slave_password=self.parameter_dict['slave_password'],
+              test_suite_title=self.parameter_dict.get('test_suite_title'),
               bin_directory=self.bin_directory,
               foo='bar',
               # botenvironemnt is splittable string of key=value to substitute
